@@ -16,11 +16,12 @@ user_data_path = pathlib.Path(platformdirs.user_data_dir(appname, appauthor))
 env_path = user_data_path / ".env"
 
 sheets_auth_json_path = user_data_path / "foundationlive-381012-3f86434e1aa2.json"
+time_data_path = user_data_path / "time_data.yaml"
 
 template_str = f"""
 FOUNDATIONLIVE_TEMPLATES_OUTPUT_DIRECTORY={user_data_path}
 FOUNDATIONLIVE_GOOGLESHEETS_AUTH_JSON_FILE_PATH={sheets_auth_json_path}
-FOUNDATIONLIVE_DATA_PATH=~/Documents/time_data.yaml
+FOUNDATIONLIVE_DATA_PATH={time_data_path}
 FOUNDATIONLIVE_GOOGLESHEETS_WORKBOOK_NAME=where does my time go
 HOURLY_RATE=100.00
 """.strip()  # noqa: E501
