@@ -24,6 +24,7 @@ import argparse
 import copy
 import logging
 import pathlib
+import platform
 import sys
 
 import yaml
@@ -31,7 +32,7 @@ import yaml
 from foundationlive import __version__, lib
 
 from . import config as configmod
-from . import googlesheets, menu, model
+from . import googlesheets, model
 from . import writer as writermod
 
 __author__ = "Taylor Monacelli"
@@ -40,6 +41,11 @@ __license__ = "MIT"
 
 _logger = logging.getLogger(__name__)
 
+try:
+    import menu
+except NotImplementedError:
+    _logger.debug("simple_term_menu isn't supported on windows")
+
 
 # ---- Python API ----
 # The functions defined in this section can be imported by users in their
@@ -214,11 +220,10 @@ def main(args):
         out = lib.view_google_sheets(timesheet_filtered)
         googlesheets.main(out)
 
+    windows = platform.system() == "Windows" or platform.system().startswith("CYGWIN")
     if args.show_reports:
-        try:
+        if not windows:
             menu.main()
-        except NotImplementedError:
-            _logger.debug("simple_term_menu isn't supported on windows")
 
 
 def run():
